##  Applicable Use Cases
[Obsolescence Risk Management](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management?locale=en-US&state=PRODUCTION&version=CLOUD "Learn why obsolescence risk management matters, how to discover risks associated with obsolete technology, how to assess their business impact, and how to efficiently manage and address them with SAP LeanIX."): The IT component fact sheet comes into play and makes the most sense if your organization needs to manage risks and get visibility of the technology that your enterprise architecture relies on. There are also compliance-related scenarios in which it will be relevant to understand and track who provides your technology and where it is hosted.
